import { PromotedObjectType } from './enum';
/**推广目标类型*/
export interface SysPromotedObjectDTO {
  promotedObjectType: PromotedObjectType;
}
/**oCPC/oCPM 优化转化行为配置*/ 
export interface DeepConversionBehaviorSpec {
    goal: string,
    bidAmount: number,
}
/**oCPC/oCPM 优化 ROI 配置*/ 
export interface DeepConversionWorthSpec {
    goal: string,
    expectedRoi: number,
}
/**oCPC/oCPM 强化 ROI 配置*/ 
export interface DeepConversionWorthAdvancedSpec {
    goal: string,
    expectedRoi: number,
}
/**oCPC/oCPM 深度优化内容*/ 
export interface DeepConversionSpec {
    deepConversionType: string,
    deepConversionBehaviorSpec: DeepConversionBehaviorSpec,
    deepConversionWorthSpec: DeepConversionWorthSpec,
    deepConversionWorthAdvancedSpec: DeepConversionWorthAdvancedSpec,
}
/**分版位组合出价系数设置*/ 
export interface SiteSetPackageStruct {
    siteSet: Array<string>,
    bidCoefficient: number,
    deepBidCoefficient: number,
}
/**分城市组合出价系数设置*/
export interface RegionGroupPackageStruct {
    regionList: Array<number>,
    bidCoefficient: number,
    deepBidCoefficient: number,
}

/**出价系数设置内容*/ 
export interface BidAdjustment {
    siteSetPackage: Array<SiteSetPackageStruct>,
    regionGroupPackage: Array<RegionGroupPackageStruct>,
}
/**年龄定向范围*/ 
export interface AgeStruct {
    min: number,
    max: number,
}
/**排除已转化用户定向*/ 
export interface ExcludedConvertedAudience {
    excludedDimension: string,
    conversionBehaviorList: Array<string>,
}
/**智能定向 —— 不可突破定向详细设置*/ 
export interface UnbreakableTargetingSetting {
    age: Array<AgeStruct>,
    gender: Array<string>,
    geoLocation: GeoLocations,
    userOs: Array<string>,
    appInstallStatus: Array<string>,
    excludedConvertedAudience: ExcludedConvertedAudience,
}


/**智能定向功能,功能灰度开放，如需使用可联系您的运营接口同学。*/ 
export interface SmartTargeting {
    smartTargetingVersion: number,
    smartTargetingSwitch: Boolean,
    startAudience: List<number>,
    unbreakableTargeting: UnbreakableTargetingSetting,
}


/**广告参数*/
export interface SysAdgroupsDTO {
  adgroupName: string; //广告名称
  promotedObjectType: string; //推广目标类型
  beginDate: Date; //开始投放日期
  firstDayBeginTime: string; //首日开始投放时间
  endDate: Date; //结束投放日期
  billingEvent: string; //计费类型
  bidAmount: number; //广告出价
  optimizationGoal: string; //	广告优化目标类型
  timeSeries: string; //投放时间段
  automaticSiteEnabled: boolean; //是否开启自动版位功能
  siteSet: Set<string>; //投放版位集合
  dailyBudget: number; //广告组日预算
  sysPromotedObjectId: number; //推广目标 id
  sysPromotedObject: SysPromotedObjectDTO; //推广目标类型
  appAndroidChannelPackageId: number; //安卓应用渠道包 id
  sysTargetingId: number; //	定向 id，仅非朋友圈广告有效
  sysTargeting: SysTargetingDTO; //定向详细设置，存放所有定向条件
  sceneSpec: SceneTargetingForWrite; //场景定向
  flowOptimizationEnabled: boolean; //是否使用智能场景匹配
  configuredStatus: string; //客户设置的状态
  customizedCategory: string; //自定义分类
  dynamicAdSpec: DynamicAdSpec; //动态商品广告属性
  userActionSets: Array<UserActionSetStruct>; //用户行为数据源
  additionalUserActionSets: Array<UserActionSetStruct>;
  bidStrategy: string; //出价策略
  coldStartAudience: Array<number>; //扩量种子人群
  autoAudience: boolean; //是否使用系统优选
  expandEnabled: boolean; //是否使用自动扩量
  expandTargeting: Array<string>; //扩量不可突破定向
  deepConversionSpec: DeepConversionSpec; //oCPC/oCPM 深度优化内容
  deepOptimizationActionType: string; //oCPC/oCPM 深度优化方式配置
  poiList: Array<string>; //门店 id 列表
  conversionId: number; //转化 id
  deepConversionBehaviorBid: number; //深度优化行为的出价
  deepConversionWorthRate: BigDecimal; //深度优化价值的期望 ROI
  deepConversionWorthAdvancedRate: BigDecimal; //强化优化价值的期望 ROI
  bidMode: string; //出价方式
  bidAdjustment: BidAdjustment; //出价系数设置内容
  autoAcquisitionEnabled: boolean; //是否开启一键起量
  autoAcquisitionBudget: number; //一键起量探索预算
  creativeDisplayType: string; //创意展示类型
  autoDerivedCreativeEnabled: boolean; //是否开启自动衍生视频创意
  smartBidType: string; //出价类型
  marketingScene: string; //营销目标
  customAdgroupTag: Array<string>; //广告标签
  smartTargeting: SmartTargeting; //智能定向功能,功能灰度开放，如需使用可联系您的运营接口同学。
}
// 列表接口返回数据
export interface ListData<T> {
  countId: number;
  current: number;
  maxLimit: any;
  optimizeCountSql: boolean;
  orders: any[];
  pages: number;
  records: T[];
  searchCount: boolean;
  size: number;
  total: number;
}
